@@ -2,7 +2,9 @@
  *
  * Static file server Ulfius callback
  *
- * Copyright 2017 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2017-2018 Nicolas Mora <mail@babelouest.org>
+ *
+ * Version 20180607
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -42,20 +44,20 @@ const char * get_filename_ext(const char *path) {
  * Streaming callback function to ease sending large files
  */
 static ssize_t callback_static_file_stream(void * cls, uint64_t pos, char * buf, size_t max) {
-  if (cls != NULL) {
-    return fread (buf, 1, max, (FILE *)cls);
-  } else {
-    return U_STREAM_END;
-  }
+	if (cls != NULL) {
+		return fread (buf, 1, max, (FILE *)cls);
+	} else {
+		return U_STREAM_END;
+	}
 }
 
 /**
  * Cleanup FILE* structure when streaming is complete
  */
 static void callback_static_file_stream_free(void * cls) {
-  if (cls != NULL) {
-    fclose((FILE *)cls);
-  }
+	if (cls != NULL) {
+		fclose((FILE *)cls);
+	}
 }
 
 /**
@@ -67,13 +69,13 @@ int callback_static_file (const struct _u_request * request, struct _u_response
   char * file_requested, * file_path, * url_dup_save;
   const char * content_type;
 
-  /*
-   * Comment this if statement if you put static files url not in root, like /app
-   */
-  if (response->shared_data != NULL) {
-    return U_CALLBACK_CONTINUE;
-  }
-  
+	/*
+	 * Comment this if statement if you put static files url not in root, like /app
+	 */
+	if (response->shared_data != NULL) {
+		return U_CALLBACK_CONTINUE;
+	}
+	
   if (user_data != NULL && ((struct _static_file_config *)user_data)->files_path != NULL) {
     file_requested = o_strdup(request->http_url);
     url_dup_save = file_requested;
@@ -107,21 +109,25 @@ int callback_static_file (const struct _u_request * request, struct _u_response
         fseek (f, 0, SEEK_END);
         length = ftell (f);
         fseek (f, 0, SEEK_SET);
-        
+				
         content_type = u_map_get_case(((struct _static_file_config *)user_data)->mime_types, get_filename_ext(file_requested));
         if (content_type == NULL) {
           content_type = u_map_get(((struct _static_file_config *)user_data)->mime_types, "*");
           y_log_message(Y_LOG_LEVEL_WARNING, "Static File Server - Unknown mime type for extension %s", get_filename_ext(file_requested));
         }
         u_map_put(response->map_header, "Content-Type", content_type);
-        u_map_put(response->map_header, "Cache-Control", "public, max-age=31536000");
-        
-        if (ulfius_set_stream_response(response, 200, callback_static_file_stream, callback_static_file_stream_free, length, STATIC_FILE_CHUNK, f) != U_OK) {
-          y_log_message(Y_LOG_LEVEL_ERROR, "callback_static_file - Error ulfius_set_stream_response");
-        }
+				
+				if (ulfius_set_stream_response(response, 200, callback_static_file_stream, callback_static_file_stream_free, length, STATIC_FILE_CHUNK, f) != U_OK) {
+					y_log_message(Y_LOG_LEVEL_ERROR, "callback_static_file - Error ulfius_set_stream_response");
+				}
       }
     } else {
-      ulfius_set_string_body_response(response, 404, "File not found");
+      if (((struct _static_file_config *)user_data)->redirect_on_404 == NULL) {
+        ulfius_set_string_body_response(response, 404, "File not found");
+      } else {
+        ulfius_add_header_to_response(response, "Location", ((struct _static_file_config *)user_data)->redirect_on_404);
+        response->status = 302;
+      }
     }
     o_free(file_path);
     o_free(url_dup_save);
