@@ -1,8 +1,12 @@
 /**
+ *
+ * Version 20180607
+ *
  * struct static_file_config must be initialized with proper values
  * files_path: path (relative or absolute) to the DocumentRoot folder
  * url_prefix: prefix used to access the callback function
  * mime_types: a struct _u_map filled with all the mime-types needed for a static file server
+ * redirect_on_404: redirct uri on error 404, if NULL, send 404
  * 
  * example of mime-types used in Hutch:
  * {
@@ -61,6 +65,7 @@ struct _static_file_config {
   char          * files_path;
   char          * url_prefix;
   struct _u_map * mime_types;
+	char          * redirect_on_404;
 };
 
 int callback_static_file (const struct _u_request * request, struct _u_response * response, void * user_data);
