@@ -18,7 +18,7 @@
 
 #define U_DISABLE_CURL
 #define U_DISABLE_WEBSOCKET
-#include "../../src/ulfius.h"
+#include "../../include/ulfius.h"
 
 #define PORT 7437
 #define PREFIX "/sheep"
