@@ -21,14 +21,17 @@
 
 #define U_DISABLE_JANSSON
 #define U_DISABLE_CURL
-#include "../../src/ulfius.h"
+#include "../../include/ulfius.h"
 
-#include <static_file_callback.h>
+#include "../../example_callbacks/static_file/static_file_callback.h"
 
 #define PORT 9275
 #define PREFIX_WEBSOCKET "/websocket"
 #define PREFIX_STATIC "/static"
 
+#if defined(U_DISABLE_WEBSOCKET)
+  #error Ulfius is not available with WebSockets support
+#else
 int callback_websocket (const struct _u_request * request, struct _u_response * response, void * user_data);
 
 /**
@@ -169,6 +172,7 @@ void websocket_onclose_callback (const struct _u_request * request,
                                 void * websocket_onclose_user_data) {
   if (websocket_onclose_user_data != NULL) {
     y_log_message(Y_LOG_LEVEL_DEBUG, "websocket_onclose_user_data is %s", websocket_onclose_user_data);
+    o_free(websocket_onclose_user_data);
   }
 }
 
@@ -184,11 +188,16 @@ void websocket_manager_callback(const struct _u_request * request,
   if (websocket_manager_user_data != NULL) {
     y_log_message(Y_LOG_LEVEL_DEBUG, "websocket_manager_user_data is %s", websocket_manager_user_data);
   }
-  for (i=0; i<5; i++) {
+  for (i=0;; i++) {
     sleep(2);
     if (websocket_manager != NULL && websocket_manager->connected) {
-      my_message = msprintf("Send message #%d", i);
-      ret = ulfius_websocket_send_message(websocket_manager, U_WEBSOCKET_OPCODE_TEXT, o_strlen(my_message), my_message);
+      if (i%2) {
+        my_message = msprintf("Send text message #%d", i);
+        ret = ulfius_websocket_send_message(websocket_manager, U_WEBSOCKET_OPCODE_TEXT, o_strlen(my_message), my_message);
+      } else {
+        my_message = msprintf("Send binary message #%d", i);
+        ret = ulfius_websocket_send_message(websocket_manager, U_WEBSOCKET_OPCODE_BINARY, o_strlen(my_message), my_message);
+      }
       o_free(my_message);
       if (ret != U_OK) {
         y_log_message(Y_LOG_LEVEL_DEBUG, "Error send message");
@@ -234,10 +243,13 @@ void websocket_incoming_message_callback (const struct _u_request * request,
  * Ulfius main callback function that simplu calls the websocket manager and closes
  */
 int callback_websocket (const struct _u_request * request, struct _u_response * response, void * user_data) {
-  char * websocket_user_data = "my_user_data";
-  if (ulfius_set_websocket_response(response, NULL, NULL, &websocket_manager_callback, websocket_user_data, &websocket_incoming_message_callback, websocket_user_data, &websocket_onclose_callback, websocket_user_data) == U_OK) {
+  char * websocket_user_data = o_strdup("my_user_data");
+  int ret;
+  
+  if ((ret = ulfius_set_websocket_response(response, NULL, NULL, &websocket_manager_callback, websocket_user_data, &websocket_incoming_message_callback, websocket_user_data, &websocket_onclose_callback, websocket_user_data)) == U_OK) {
     return U_CALLBACK_CONTINUE;
   } else {
     return U_CALLBACK_ERROR;
   }
 }
+#endif
