@@ -23,7 +23,7 @@
  * 
  */
 #include "u_private.h"
-#include "ulfius.h"
+#include "../include/ulfius.h"
 
 #ifndef U_DISABLE_CURL
 
@@ -203,16 +203,16 @@ int ulfius_send_http_streaming_request(const struct _u_request * request, struct
           return U_ERROR_LIBCURL;
         }
       }
-			
-			// Set proxy if defined
-			if (copy_request->proxy != NULL) {
-				if (curl_easy_setopt(curl_handle, CURLOPT_PROXY, copy_request->proxy) != CURLE_OK) {
+      
+      // Set proxy if defined
+      if (copy_request->proxy != NULL) {
+        if (curl_easy_setopt(curl_handle, CURLOPT_PROXY, copy_request->proxy) != CURLE_OK) {
           y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error setting proxy option");
           ulfius_clean_request_full(copy_request);
           curl_easy_cleanup(curl_handle);
           return U_ERROR_LIBCURL;
-				}
-			}
+        }
+      }
       
       has_params = (o_strchr(copy_request->http_url, '?') != NULL);
       if (copy_request->map_url != NULL && u_map_count(copy_request->map_url) > 0) {
@@ -649,7 +649,11 @@ static size_t smtp_payload_source(void * ptr, size_t size, size_t nmemb, void *
       y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error allocating memory for MAIL_DATE\n");
       return 0;
     } else {
+#ifdef _WIN32
+      strftime(data, 128, "Date: %a, %d %b %Y %H:%M:%S %z\r\n", gmtime(&now));
+#else
       strftime(data, 128, "Date: %a, %d %b %Y %T %z\r\n", gmtime(&now));
+#endif
       len = strlen(data);
     }
   } else if (upload_ctx->lines_read == MAIL_TO) {
