@@ -24,7 +24,7 @@
  */
 
 #include "u_private.h"
-#include "ulfius.h"
+#include "../include/ulfius.h"
 
 #ifndef U_DISABLE_WEBSOCKET
 #include <string.h>
@@ -108,6 +108,8 @@ void * ulfius_thread_websocket(void * data) {
   pthread_t thread_websocket_manager;
   pthread_mutexattr_t mutexattr;
   int thread_ret_websocket_manager = 0, poll_ret;
+  int error = 0;
+  socklen_t len = sizeof (error);
   
   if (websocket != NULL && websocket->websocket_manager != NULL) {
     pthread_mutexattr_init ( &mutexattr );
@@ -132,31 +134,46 @@ void * ulfius_thread_websocket(void * data) {
       if (pthread_mutex_lock(&websocket->websocket_manager->read_lock)) {
         websocket->websocket_manager->connected = 0;
       }
-      poll_ret = poll(&websocket->websocket_manager->fds, 1, U_WEBSOCKET_USEC_WAIT);
-      if (poll_ret == -1) {
-        y_log_message(Y_LOG_LEVEL_ERROR, "Error poll websocket read");
-      } else if (poll_ret > 0) {
-        opcode = ulfius_read_incoming_message(websocket->websocket_manager, &message);
-        if (opcode == U_WEBSOCKET_OPCODE_CLOSE) {
-          // Send close command back, then close the socket
-          if (ulfius_websocket_send_message(websocket->websocket_manager, U_WEBSOCKET_OPCODE_CLOSE, 0, NULL) != U_OK) {
-            y_log_message(Y_LOG_LEVEL_ERROR, "Error sending close command");
-          }
-          websocket->websocket_manager->closing = 1;
-        } else if (opcode == U_WEBSOCKET_OPCODE_PING) {
-          // Send pong command
-          if (ulfius_websocket_send_message(websocket->websocket_manager, U_WEBSOCKET_OPCODE_PONG, 0, NULL) != U_OK) {
-            y_log_message(Y_LOG_LEVEL_ERROR, "Error sending pong command");
-          }
-        } else if (opcode != U_WEBSOCKET_OPCODE_NONE && message != NULL) {
-          if (websocket->websocket_incoming_message_callback != NULL) {
-            // TODO: run in thread
-            websocket->websocket_incoming_message_callback(websocket->request, websocket->websocket_manager, message, websocket->websocket_incoming_user_data);
-          }
-        }
-        if (message != NULL) {
-          if (ulfius_push_websocket_message(websocket->websocket_manager->message_list_incoming, message) != U_OK) {
-            y_log_message(Y_LOG_LEVEL_ERROR, "Error pushing new websocket message in list");
+      error = 0;
+      poll_ret = getsockopt(websocket->websocket_manager->sock, SOL_SOCKET, SO_ERROR, &error, &len);
+      if (poll_ret != 0) {
+        y_log_message(Y_LOG_LEVEL_ERROR, "Error getsockopt");
+        websocket->websocket_manager->connected = 0;
+      } else {
+        if (error != 0) {
+          y_log_message(Y_LOG_LEVEL_ERROR, "Socket not good enough");
+          websocket->websocket_manager->connected = 0;
+        } else {
+          poll_ret = poll(&websocket->websocket_manager->fds, 1, U_WEBSOCKET_USEC_WAIT);
+          if (poll_ret == -1) {
+            y_log_message(Y_LOG_LEVEL_ERROR, "Error poll websocket read");
+            websocket->websocket_manager->connected = 0;
+          } else if (websocket->websocket_manager->fds.revents & (POLLRDHUP|POLLERR|POLLHUP|POLLNVAL)) {
+            websocket->websocket_manager->connected = 0;
+          } else if (poll_ret > 0) {
+            opcode = ulfius_read_incoming_message(websocket->websocket_manager, &message);
+            if (opcode == U_WEBSOCKET_OPCODE_CLOSE) {
+              // Send close command back, then close the socket
+              if (ulfius_websocket_send_message(websocket->websocket_manager, U_WEBSOCKET_OPCODE_CLOSE, 0, NULL) != U_OK) {
+                y_log_message(Y_LOG_LEVEL_ERROR, "Error sending close command");
+              }
+              websocket->websocket_manager->closing = 1;
+            } else if (opcode == U_WEBSOCKET_OPCODE_PING) {
+              // Send pong command
+              if (ulfius_websocket_send_message(websocket->websocket_manager, U_WEBSOCKET_OPCODE_PONG, 0, NULL) != U_OK) {
+                y_log_message(Y_LOG_LEVEL_ERROR, "Error sending pong command");
+              }
+            } else if (opcode != U_WEBSOCKET_OPCODE_NONE && message != NULL) {
+              if (websocket->websocket_incoming_message_callback != NULL) {
+                // TODO: run in thread
+                websocket->websocket_incoming_message_callback(websocket->request, websocket->websocket_manager, message, websocket->websocket_incoming_user_data);
+              }
+            }
+            if (message != NULL) {
+              if (ulfius_push_websocket_message(websocket->websocket_manager->message_list_incoming, message) != U_OK) {
+                y_log_message(Y_LOG_LEVEL_ERROR, "Error pushing new websocket message in list");
+              }
+            }
           }
         }
       }
@@ -178,16 +195,20 @@ void * ulfius_thread_websocket(void * data) {
  * Websocket callback function for MHD
  * Starts the websocket manager if set,
  */
-void ulfius_start_websocket_cb (void *cls,
-            struct MHD_Connection *connection,
+void ulfius_start_websocket_cb (void * cls,
+            struct MHD_Connection * connection,
             void * con_cls,
             const char * extra_in,
             size_t extra_in_size,
             MHD_socket sock,
             struct MHD_UpgradeResponseHandle * urh) {
-  struct _websocket * websocket = (struct _websocket*)cls;
+  struct _websocket * websocket = (struct _websocket *)cls;
   pthread_t thread_websocket;
   int thread_ret_websocket = 0, thread_detach_websocket = 0;
+  UNUSED(connection);
+  UNUSED(con_cls);
+  UNUSED(extra_in);
+  UNUSED(extra_in_size);
   
   if (websocket != NULL) {
     websocket->urh = urh;
@@ -200,7 +221,7 @@ void ulfius_start_websocket_cb (void *cls,
       ulfius_init_websocket_message_list(websocket->websocket_manager->message_list_outcoming);
       websocket->websocket_manager->sock = sock;
       websocket->websocket_manager->fds.fd = sock;
-      websocket->websocket_manager->fds.events = POLLIN;
+      websocket->websocket_manager->fds.events = POLLIN | POLLRDHUP;
       websocket->websocket_manager->connected = 1;
       websocket->websocket_manager->closing = 0;
       thread_ret_websocket = pthread_create(&thread_websocket, NULL, ulfius_thread_websocket, (void *)websocket);
@@ -287,11 +308,11 @@ int ulfius_read_incoming_message(struct _websocket_manager * websocket_manager,
             if (msg_len > 0) {
               payload_data = o_malloc(msg_len*sizeof(uint8_t));
               len = ulfius_websocket_recv_all(websocket_manager->sock, payload_data, msg_len);
-              if (len == msg_len) {
+              if ((unsigned int)len == msg_len) {
                 // If mask, decode message
                 if ((*message)->has_mask) {
                   (*message)->data = o_realloc((*message)->data, (msg_len+(*message)->data_len)*sizeof(uint8_t));
-                  for (i = (*message)->data_len; i < msg_len; i++) {
+                  for (i = (*message)->data_len; (unsigned int)i < msg_len; i++) {
                     (*message)->data[i] = payload_data[i-(*message)->data_len] ^ masking_key[(i-(*message)->data_len)%4];
                   }
                 } else {
@@ -343,7 +364,7 @@ int ulfius_clear_websocket(struct _websocket * websocket) {
     }
     ulfius_instance_remove_websocket_active(websocket->instance, websocket);
     ulfius_clear_websocket_manager(websocket->websocket_manager);
-		ulfius_clean_request_full(websocket->request);
+    ulfius_clean_request_full(websocket->request);
     o_free(websocket->websocket_manager);
     websocket->websocket_manager = NULL;
     o_free(websocket);
@@ -492,7 +513,7 @@ int ulfius_websocket_send_message(struct _websocket_manager * websocket_manager,
       poll_ret = poll(&websocket_manager->fds, 1, U_WEBSOCKET_USEC_WAIT);
       if (poll_ret == -1) {
         y_log_message(Y_LOG_LEVEL_ERROR, "Error poll websocket read for close signal");
-      } else if (poll_ret > 0) {
+      } else if (!(websocket_manager->fds.revents & (POLLRDHUP|POLLERR|POLLHUP|POLLNVAL)) && poll_ret > 0) {
         do {
           ret_message = ulfius_read_incoming_message(websocket_manager, &message);
           if (message != NULL) {
@@ -605,7 +626,7 @@ int ulfius_websocket_send_message_nolock(struct _websocket_manager * websocket_m
 void ulfius_websocket_send_all(MHD_socket sock, const uint8_t * data, size_t len) {
   ssize_t ret = 0, off;
   if (data != NULL && len > 0) {
-    for (off = 0; off < len; off += ret) {
+    for (off = 0; (size_t)off < len; off += ret) {
       ret = send(sock, &data[off], len - off, MSG_NOSIGNAL);
       if (ret < 0) {
         break;
@@ -627,7 +648,7 @@ size_t ulfius_websocket_recv_all(MHD_socket sock, uint8_t * data, size_t len) {
  * If match is NULL, then return source duplicate
  * Returned value must be u_free'd after use
  */
-char * ulfius_check_list_match(const char * source, const char * match) {
+char * ulfius_check_list_match(const char * source, const char * match, const char * separator) {
   char ** source_list = NULL, ** match_list = NULL;
   char * to_return = NULL;
   int i;
@@ -635,13 +656,13 @@ char * ulfius_check_list_match(const char * source, const char * match) {
     to_return = o_strdup(source);
   } else {
     if (source != NULL) {
-      if (split_string(source, ",", &source_list) > 0 && split_string(match, ",", &match_list) > 0) {
+      if (split_string(source, separator, &source_list) > 0 && split_string(match, separator, &match_list) > 0) {
         for (i=0; source_list[i] != NULL; i++) {
           if (string_array_has_trimmed_value((const char **)match_list, source_list[i])) {
             if (to_return == NULL) {
               to_return = o_strdup(trimwhitespace(source_list[i]));
             } else {
-              char * tmp = msprintf("%s, %s", to_return, trimwhitespace(source_list[i]));
+              char * tmp = msprintf("%s%s %s", to_return, separator, trimwhitespace(source_list[i]));
               o_free(to_return);
               to_return = tmp;
             }
@@ -655,12 +676,46 @@ char * ulfius_check_list_match(const char * source, const char * match) {
   return to_return;
 }
 
+/**
+ * Return the first match between two list of items
+ * If match is NULL, then return the first element of source
+ * Returned value must be u_free'd after use
+ */
+char * ulfius_check_first_match(const char * source, const char * match, const char * separator) {
+  char ** source_list = NULL, ** match_list = NULL;
+  char * to_return = NULL;
+  int i;
+  if (match == NULL) {
+    if (source != NULL) {
+      if (split_string(source, separator, &source_list) > 0) {
+        to_return = o_strdup(trimwhitespace(source_list[0]));
+      }
+      free_string_array(source_list);
+    }
+  } else {
+    if (source != NULL) {
+      if (split_string(source, separator, &source_list) > 0 && split_string(match, separator, &match_list) > 0) {
+        for (i=0; source_list[i] != NULL && to_return == NULL; i++) {
+          if (string_array_has_trimmed_value((const char **)match_list, source_list[i])) {
+            if (to_return == NULL) {
+              to_return = o_strdup(trimwhitespace(source_list[i]));
+            }
+          }
+        }
+        free_string_array(source_list);
+        free_string_array(match_list);
+      }
+    }
+  }
+  return to_return;
+}
+
 /**
  * Close the websocket
  */
 int ulfius_close_websocket(struct _websocket * websocket) {
   if (websocket != NULL && websocket->websocket_manager != NULL) {
-    if (websocket->websocket_onclose_callback != NULL && websocket->websocket_manager->connected) {
+    if (websocket->websocket_onclose_callback != NULL) {
       // Call websocket_onclose_callback if set
       websocket->websocket_onclose_callback(websocket->request, websocket->websocket_manager, websocket->websocket_onclose_user_data);
     }
