@@ -27,7 +27,7 @@
 #include <stdlib.h>
 #include <pthread.h>
 #include "u_private.h"
-#include "ulfius.h"
+#include "../include/ulfius.h"
 
 /**
  * Fill a map with the key/values specified
@@ -35,6 +35,7 @@
 static int ulfius_fill_map(void * cls, enum MHD_ValueKind kind, const char * key, const char * value) {
   char * tmp;
   int res;
+  UNUSED(kind);
   
   if (cls == NULL || key == NULL) {
     // Invalid parameters
@@ -125,9 +126,12 @@ static int ulfius_validate_instance(const struct _u_instance * u_instance) {
  */
 static void * ulfius_uri_logger (void * cls, const char * uri) {
   struct connection_info_struct * con_info = o_malloc (sizeof (struct connection_info_struct));
+  UNUSED(cls);
+  
   if (con_info != NULL) {
     con_info->callback_first_iteration = 1;
     con_info->u_instance = NULL;
+    u_map_init(&con_info->map_url_initial);
     con_info->request = o_malloc(sizeof(struct _u_request));
     if (con_info->request == NULL) {
       y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error allocating memory for con_info->request");
@@ -195,6 +199,10 @@ static int ulfius_get_body_from_response(struct _u_response * response, void **
 static void mhd_request_completed (void *cls, struct MHD_Connection *connection,
                         void **con_cls, enum MHD_RequestTerminationCode toe) {
   struct connection_info_struct *con_info = *con_cls;
+  UNUSED(toe);
+  UNUSED(connection);
+  UNUSED(cls);
+  
   if (NULL == con_info) {
     return;
   }
@@ -222,6 +230,7 @@ static int mhd_iterate_post_data (void * coninfo_cls, enum MHD_ValueKind kind, c
   struct connection_info_struct * con_info = coninfo_cls;
   size_t cur_size = size;
   char * data_dup, * filename_param;
+  UNUSED(kind);
   
   if (filename != NULL && con_info->u_instance != NULL && con_info->u_instance->file_upload_callback != NULL) {
     if (con_info->u_instance->file_upload_callback(con_info->request, key, filename, content_type, transfer_encoding, data, off, size, con_info->u_instance->file_upload_cls) == U_OK) {
@@ -300,7 +309,6 @@ static int ulfius_webservice_dispatcher (void * cls, struct MHD_Connection * con
     so_client = MHD_get_connection_info (connection, MHD_CONNECTION_INFO_CLIENT_ADDRESS)->client_addr;
     con_info->has_post_processor = 0;
     con_info->max_post_param_size = ((struct _u_instance *)cls)->max_post_param_size;
-    u_map_init(&con_info->map_url_initial);
     con_info->request->http_protocol = o_strdup(version);
     con_info->request->http_verb = o_strdup(method);
     con_info->request->client_address = o_malloc(sizeof(struct sockaddr));
@@ -424,57 +432,60 @@ static int ulfius_webservice_dispatcher (void * cls, struct MHD_Connection * con
                 NULL != o_strcasestr(u_map_get_case(con_info->request->map_header, "Connection"), "Upgrade") &&
                 0 == o_strcmp(con_info->request->http_verb, "GET")) {
               // Check websocket_protocol and websocket_extensions to match ours
-              char * extensions = ulfius_check_list_match(u_map_get(con_info->request->map_header, "Sec-WebSocket-Extensions"), ((struct _websocket_handle *)response->websocket_handle)->websocket_extensions),
-                   * protocol = ulfius_check_list_match(u_map_get(con_info->request->map_header, "Sec-WebSocket-Protocol"), ((struct _websocket_handle *)response->websocket_handle)->websocket_protocol);
+              char * extensions = ulfius_check_list_match(u_map_get(con_info->request->map_header, "Sec-WebSocket-Extensions"), ((struct _websocket_handle *)response->websocket_handle)->websocket_extensions, ";"),
+                   * protocol = ulfius_check_first_match(u_map_get(con_info->request->map_header, "Sec-WebSocket-Protocol"), ((struct _websocket_handle *)response->websocket_handle)->websocket_protocol, ",");
               if (extensions != NULL && protocol != NULL) {
                 char websocket_accept[32] = {0};
                 if (ulfius_generate_handshake_answer(u_map_get(con_info->request->map_header, "Sec-WebSocket-Key"), websocket_accept)) {
                   struct _websocket * websocket = o_malloc(sizeof(struct _websocket));
                   if (websocket != NULL) {
                     websocket->request = ulfius_duplicate_request(con_info->request);
-										if (websocket->request != NULL) {
-											websocket->instance = (struct _u_instance *)cls;
-											websocket->websocket_protocol = ((struct _websocket_handle *)response->websocket_handle)->websocket_protocol;
-											websocket->websocket_extensions = ((struct _websocket_handle *)response->websocket_handle)->websocket_extensions;
-											websocket->websocket_manager_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_manager_callback;
-											websocket->websocket_manager_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_manager_user_data;
-											websocket->websocket_incoming_message_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_incoming_message_callback;
-											websocket->websocket_incoming_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_incoming_user_data;
-											websocket->websocket_onclose_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_onclose_callback;
-											websocket->websocket_onclose_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_onclose_user_data;
-											websocket->tls = 0;
-											mhd_response = MHD_create_response_for_upgrade(ulfius_start_websocket_cb, websocket);
-											if (mhd_response == NULL) {
-												y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error MHD_create_response_for_upgrade");
-												mhd_ret = MHD_NO;
-											} else {
-												MHD_add_response_header (mhd_response,
-																								 MHD_HTTP_HEADER_UPGRADE,
-																								 U_WEBSOCKET_UPGRADE_VALUE);
-												MHD_add_response_header (mhd_response,
-																								 "Sec-WebSocket-Accept",
-																								 websocket_accept);
-												if (ulfius_set_response_header(mhd_response, response->map_header) == -1 || ulfius_set_response_cookie(mhd_response, response) == -1) {
-													y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error setting headers or cookies");
-													mhd_ret = MHD_NO;
-												} else {
-													ulfius_instance_add_websocket_active((struct _u_instance *)cls, websocket);
-													upgrade_protocol = 1;
-												}
-											}
-										} else {
-											o_free(websocket);
-											// Error building struct _websocket, sending error 500
-											response->status = MHD_HTTP_INTERNAL_SERVER_ERROR;
-											response_buffer = o_strdup(ULFIUS_HTTP_ERROR_BODY);
-											if (response_buffer == NULL) {
-												y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error allocating memory for websocket->request");
-												mhd_ret = MHD_NO;
-											} else {
-												response_buffer_len = strlen(ULFIUS_HTTP_ERROR_BODY);
-												mhd_response = MHD_create_response_from_buffer (response_buffer_len, response_buffer, MHD_RESPMEM_MUST_FREE );
-											}
-										}
+                    if (websocket->request != NULL) {
+                      websocket->instance = (struct _u_instance *)cls;
+                      websocket->websocket_protocol = ((struct _websocket_handle *)response->websocket_handle)->websocket_protocol;
+                      websocket->websocket_extensions = ((struct _websocket_handle *)response->websocket_handle)->websocket_extensions;
+                      websocket->websocket_manager_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_manager_callback;
+                      websocket->websocket_manager_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_manager_user_data;
+                      websocket->websocket_incoming_message_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_incoming_message_callback;
+                      websocket->websocket_incoming_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_incoming_user_data;
+                      websocket->websocket_onclose_callback = ((struct _websocket_handle *)response->websocket_handle)->websocket_onclose_callback;
+                      websocket->websocket_onclose_user_data = ((struct _websocket_handle *)response->websocket_handle)->websocket_onclose_user_data;
+                      websocket->tls = 0;
+                      mhd_response = MHD_create_response_for_upgrade(ulfius_start_websocket_cb, websocket);
+                      if (mhd_response == NULL) {
+                        y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error MHD_create_response_for_upgrade");
+                        mhd_ret = MHD_NO;
+                      } else {
+                        MHD_add_response_header (mhd_response,
+                                                 MHD_HTTP_HEADER_UPGRADE,
+                                                 U_WEBSOCKET_UPGRADE_VALUE);
+                        MHD_add_response_header (mhd_response,
+                                                 "Sec-WebSocket-Accept",
+                                                 websocket_accept);
+                        MHD_add_response_header (mhd_response,
+                                                 "Sec-WebSocket-Protocol",
+                                                 protocol);
+                        if (ulfius_set_response_header(mhd_response, response->map_header) == -1 || ulfius_set_response_cookie(mhd_response, response) == -1) {
+                          y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error setting headers or cookies");
+                          mhd_ret = MHD_NO;
+                        } else {
+                          ulfius_instance_add_websocket_active((struct _u_instance *)cls, websocket);
+                          upgrade_protocol = 1;
+                        }
+                      }
+                    } else {
+                      o_free(websocket);
+                      // Error building struct _websocket, sending error 500
+                      response->status = MHD_HTTP_INTERNAL_SERVER_ERROR;
+                      response_buffer = o_strdup(ULFIUS_HTTP_ERROR_BODY);
+                      if (response_buffer == NULL) {
+                        y_log_message(Y_LOG_LEVEL_ERROR, "Ulfius - Error allocating memory for websocket->request");
+                        mhd_ret = MHD_NO;
+                      } else {
+                        response_buffer_len = strlen(ULFIUS_HTTP_ERROR_BODY);
+                        mhd_response = MHD_create_response_from_buffer (response_buffer_len, response_buffer, MHD_RESPMEM_MUST_FREE );
+                      }
+                    }
                   } else {
                     // Error building struct _websocket, sending error 500
                     response->status = MHD_HTTP_INTERNAL_SERVER_ERROR;
